@@ -1,12 +1,16 @@
+import calendar
 from datetime import datetime, timedelta
 from typing import List, Optional
 
 import pytz
-from django.db.models import Count, Q, Sum
+from django.apps import apps
+from django.conf import settings
+from django.db.models import Count, Q
 from django.utils import timezone
 from music.models import Artist, Track
 from scrobbles.models import Scrobble
 from videos.models import Video
+
 from vrobbler.apps.profiles.utils import now_user_timezone
 
 NOW = timezone.now()
@@ -91,6 +95,59 @@ def week_of_scrobbles(user=None, media: str = 'tracks') -> dict[str, int]:
     return scrobble_day_dict
 
 
+def aggregator(
+    year: Optional[int] = None,
+    month: Optional[int] = None,
+    day: Optional[int] = None,
+    user=None,
+    model_str="Track",
+) -> dict[str, int]:
+    now = timezone.now()
+    tz = settings.TIME_ZONE
+    if user and user.is_authenticated:
+        now = now_user_timezone(user.profile)
+        tz = pytz.timezone(user.profile.timezone)
+
+    data_model = apps.get_model(app_label='music', model_name='Track')
+    if model_str == "Video":
+        data_model = apps.get_model(app_label='videos', model_name='Video')
+    if model_str == "SportEvent":
+        data_model = apps.get_model(
+            app_label='sports', model_name='SportEvent'
+        )
+
+    base_qs = data_model.objects.filter(
+        scrobble__user=user,
+        scrobble__played_to_completion=True,
+    )
+
+    if not year:
+        return base_qs.annotate(scrobble_count=Count("scrobble"))
+
+    start = datetime(year, 1, 1, tzinfo=tz)
+    end = datetime(year, 12, 31, tzinfo=tz)
+    if month:
+        end_day = calendar.monthrange(year, month)[1]
+        start = datetime(year, month, 1, tzinfo=tz)
+        end = datetime(year, month, end_day, tzinfo=tz)
+    if day:
+        start = datetime(year, month, day, 0, 0, tzinfo=tz)
+        end = datetime(year, month, day, 23, 59, tzinfo=tz)
+
+    date_filter = Q(
+        scrobble__timestamp__gte=start, scrobble__timestamp__lte=end
+    )
+
+    return base_qs.annotate(
+        num_scrobbles=Count("scrobble", filter=Q(date_filter))
+    ).filter(date_filter)
+
+
+def year_of_scrobbles(user=None, media: str = 'tracks') -> dict[str, int]:
+
+    return {}
+
+
 def top_tracks(
     user: "User", filter: str = "today", limit: int = 15
 ) -> List["Track"]:
